@@ -15,7 +15,7 @@ class HeaderToLabelMiddleware(object):
     """
     Provides full logging of requests and responses
     """
-    _initial_http_body = b""
+    _initial_http_body = ""
     _request_start_time = None
     _TRUNCATE_INDICATOR = "---[TRUNCATED]---"
     _OBFUSCATE_INDICATOR = "---[HIDDEN]---"
@@ -39,7 +39,7 @@ class HeaderToLabelMiddleware(object):
         self.get_response = get_response
 
     def process_request(self, request):
-        self._initial_http_body = request.body
+        self._initial_http_body = Utils.obfuscate_body(Utils.adjust_string_length(request.body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE)))
         self._request_start_time = Utils.get_time_in_milliseconds()
         log_label_request_settings = getattr(settings, LOG_LABEL_REQUEST_SETTING, dict())
 
@@ -58,7 +58,7 @@ class HeaderToLabelMiddleware(object):
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=Utils.get_time_in_milliseconds(),
             method=request.method,
-            body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE))),
+            body=self._initial_http_body,
             url=Utils.obfuscate_url(request.build_absolute_uri())
         )
         log_entry_debug.update(headers)
@@ -74,7 +74,6 @@ class HeaderToLabelMiddleware(object):
         logger.info('', extra=log_entry_info)
 
     def process_response(self, request, response):
-        logger.debug(Utils.get_time_in_milliseconds())
         headers = Utils.obfuscate_headers(Utils.get_all_headers(request))
         status_code = 500
         if hasattr(response, "status_code"):
@@ -84,21 +83,20 @@ class HeaderToLabelMiddleware(object):
             content = response.content.decode("UTF-8")
         else:
             content = str(response)
-        logger.debug(Utils.get_time_in_milliseconds())
+
         log_entry = dict(
             type=self._RESPONSE,
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=Utils.get_time_in_milliseconds(),
             method=request.method,
-            body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body,
-                                            getattr(settings, MAX_REQUEST_RESPONSE_SIZE)) if status_code < 400 else Utils.obfuscate_body(self._initial_http_body.decode("UTF-8"))),
+            body=self._initial_http_body,
             status_code=status_code,
             response=Utils.obfuscate_response(Utils.adjust_string_length(content,
                                                 settings.MAX_REQUEST_RESPONSE_SIZE) if status_code < 400 else Utils.obfuscate_response(content)),
             url=Utils.obfuscate_url(request.build_absolute_uri())
         )
         log_entry.update(headers)
-        logger.debug(Utils.get_time_in_milliseconds())
+
         log_entry_info = dict(
             type=self._RESPONSE,
             request_start_time_ms=self._request_start_time,
@@ -107,7 +105,6 @@ class HeaderToLabelMiddleware(object):
             method=request.method,
             url=Utils.obfuscate_url(request.build_absolute_uri())
         )
-        logger.debug(Utils.get_time_in_milliseconds())
         log_entry_info.update(log_entry_info)
         log_entry_info.update(headers)
 
@@ -137,7 +134,7 @@ class HeaderToLabelMiddleware(object):
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=Utils.get_time_in_milliseconds(),
             method=request.method,
-            body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE))),
+            body=self._initial_http_body,
             status_code=500,
             exception=str(exception),
             url=Utils.obfuscate_url(request.build_absolute_uri()),
