@@ -122,28 +122,23 @@ class Utils:
                 return cls.obfuscate(data, start_index, end_index)
 
         if obfuscation_type == Obfuscation_Type.JSON:
-            indicator = '(?i)(\\"{}\\"\\s*:\\s*\\"((\\\\"|[^\\\\\"])*)\\")'.format(re.escape(field_name))
+            indicator = '(?i)((\\"{}\\"\\s*:\\s*\\")((\\\\"|[^\\\\\"])*)\\")'.format(re.escape(field_name))
             matches = re.search(indicator, data)
 
             if matches and cls.starts_with(matches.groups()[0], "\"{}\"".format(field_name)):
-                separator_reg_exp = '(?i)(\\"{}\\"\\s*:\\s*\\")'.format(re.escape(field_name))
-                separator_matches = re.search(separator_reg_exp, data)
-                {"username": "Some username", "password": "Super secret that should not be seen"}
-                start_index = data.index(matches.groups()[0]) + len(separator_matches.groups()[0])
+                start_index = data.index(matches.groups()[0]) + len(matches.groups()[1])
                 end_index = len(data[:start_index]) + cls.find_next_json_closing_quote(data[start_index:])
 
                 return cls.obfuscate(data, start_index, end_index)
 
         if obfuscation_type == Obfuscation_Type.URL:
-            indicator = "(?i)(((\\?|\\&){}=((\\\"|[^\\&])*)))".format(re.escape(field_name))
+            indicator = "(?i)((((\\?|\\&){}=)((\\\"|[^\\&])*)))".format(re.escape(field_name))
             matches = re.search(indicator, data)
 
             if matches and cls.starts_with(matches.groups()[0].lstrip("?").lstrip("&"), field_name):
                 stripped_match = matches.groups()[0].lstrip("?").lstrip("&")
-                separator_reg_exp = "(?i)((\\?|\\&){}=)".format(re.escape(field_name))
-                separator_matches = re.search(separator_reg_exp, data)
-                stripped_separator_matches = separator_matches.groups()[0].lstrip("?").lstrip("&")
-                start_index = data.index(stripped_match) + len(stripped_separator_matches)
+                key_matches = matches.groups()[2].lstrip("?").lstrip("&")
+                start_index = data.index(stripped_match) + len(key_matches)
                 try:
                     end_index = len(data[:start_index]) + data[start_index:].index("&")
                 except ValueError:
@@ -158,7 +153,9 @@ class Utils:
         log_label_obfuscate = getattr(settings, LOG_LABEL_OBFUSCATE, dict())
         if "body" in log_label_obfuscate:
             body = cls.remove_new_lines(body)
-            for field_name, obfuscation_type in log_label_obfuscate["body"].items():
+            for obfuscation in log_label_obfuscate["body"]:
+                field_name = obfuscation[0]
+                obfuscation_type = obfuscation[1]
                 body = cls.obfuscate_by_type(body, field_name, obfuscation_type)
 
         return body
@@ -168,7 +165,9 @@ class Utils:
         log_label_obfuscate = getattr(settings, LOG_LABEL_OBFUSCATE, dict())
         if "response" in log_label_obfuscate:
             response = cls.remove_new_lines(response)
-            for field_name, obfuscation_type in log_label_obfuscate["response"].items():
+            for obfuscation in log_label_obfuscate["response"]:
+                field_name = obfuscation[0]
+                obfuscation_type = obfuscation[1]
                 response = cls.obfuscate_by_type(response, field_name, obfuscation_type)
 
         return response
@@ -177,7 +176,9 @@ class Utils:
     def obfuscate_url(cls, url):
         log_label_obfuscate = getattr(settings, LOG_LABEL_OBFUSCATE, dict())
         if "url" in log_label_obfuscate:
-            for field_name, obfuscation_type in log_label_obfuscate["url"].items():
+            for obfuscation in log_label_obfuscate["url"]:
+                field_name = obfuscation[0]
+                obfuscation_type = obfuscation[1]
                 url = cls.obfuscate_by_type(url, field_name, obfuscation_type)
 
         return url
